@@ -543,9 +543,42 @@ class Bitpin:
 
         response = self._request(
             f_name,
-            'GET',
+            'POST',
             url,
-            auth=False,
+            auth=True,
+            json_data=json_data
         )
 
         return self._process_response(f_name, response, f_args)
+
+    def cancel_order(self, order_id: int) -> t.Dict:
+        
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        url = f'v1/odr/orders/{order_id}/'
+
+        response = self._request(
+            f_name,
+            'DELETE',
+            url,
+            auth=True,
+        )
+
+        return self._process_response(f_name, response, f_args)
+    
+    def recent_trades(self):
+        
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        url = 'v1/odr/orders/'
+
+        response = self._request(
+            f_name,
+            'GET',
+            url,
+            auth=True,
+        )
+
+        return self._process_response(f_name, response, f_args)
\ No newline at end of file
